:desc: Open source alternative to IBM Watson for conversational bots and NLP

.. _ibm-watson-to-rasa:

Rasa as open source alternative to IBM Watson - Migration Tips
==============================================================

.. edit-link::



.. raw:: html

     <br> There is no support for IBM Watson yet. However, a group of community members is working on a way to use <a class="reference external" href="https://developer.ibm.com/tutorials/learn-how-to-export-import-a-watson-assistant-workspace/" target="_blank">exported IBM Watson workspaces</a> in Rasa. If you're interested in that, check out our <a class="reference external" href="https://forum.rasa.com/" target="_blank">Community Forum</a>.


At Rasa, we hear a few different reasons why developers switch from cloud-based tools like IBM Watson:

* **Faster**: Runs locally - no https requests and server round trips required
* **Customizable**: Tune models and get higher accuracy with your data set
* **Open source**: No risk of vendor lock-in - Rasa comes with an Apache 2.0 licence and you can use it in commercial projects


.. raw:: html

     In addition, our open source tools allow developers to build contextual AI assistants and manage dialogues with machine learning instead of rules - learn more in <a class="reference external" href="http://blog.rasa.com/a-new-approach-to-conversational-software/" target="_blank">this blog post</a>.


.. button::
     :link: ../get_started_step1/
     :text: Learn more about Rasa
